@@ -6,15 +6,11 @@
 Module to manage the AppMesh Virtual service
 """
 
-from troposphere import AWS_NO_VALUE
-from troposphere import Ref, Sub, GetAtt, Select, Split
-from troposphere import appmesh
-from troposphere.servicediscovery import (
-    DnsConfig as SdDnsConfig,
-    Service as SdService,
-    DnsRecord as SdDnsRecord,
-    Instance as SdInstance,
-)
+from troposphere import AWS_NO_VALUE, GetAtt, Ref, Select, Split, Sub, appmesh
+from troposphere.servicediscovery import DnsConfig as SdDnsConfig
+from troposphere.servicediscovery import DnsRecord as SdDnsRecord
+from troposphere.servicediscovery import Instance as SdInstance
+from troposphere.servicediscovery import Service as SdService
 
 from ecs_composex.appmesh import appmesh_conditions
 from ecs_composex.appmesh.appmesh_params import NODE_KEY, ROUTER_KEY, ROUTERS_KEY
